//+------------------------------------------------------------------+
//|                                         WeeklyScalping Lines.mq4 |
//|                                                         SwingMan |
//|                                               soc607@t-online.de |
//+------------------------------------------------------------------+
#property copyright "SwingMan"
#property link      "soc607@t-online.de"

#property indicator_chart_window

#property indicator_buffers 8
//---- colors
#property indicator_color1 Red
#property indicator_color2 Blue
#property indicator_color3 Green
#property indicator_color4 Green
#property indicator_color5 Green
#property indicator_color6 Red
#property indicator_color7 Red
#property indicator_color8 Red

//---- extern parameters ---------------------------------------------
extern int Period_ShortAvg  = 3;
extern int Period_ATRweekly  = 34;
extern double factor_EntryOffset  = 0.20;
extern double factor_StopLoss   = 0.60;
extern double factor_Target = 2.0;
//--------------------------------------------------------------------

//---- variables
int thisTimeFrame, upperTimeFrame;
int maxPeriod;
//---- Buffers
double MavgThisTimeFrame[];
double CloseUpperTimeFrame[];
double LongEntry[], LongStop[], LongTarget[];
double ShortEntry[], ShortStop[], ShortTarget[];
double BarRange[];

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
{
   thisTimeFrame = Period();
   upperTimeFrame = PERIOD_W1;
   if (thisTimeFrame > upperTimeFrame) return(0);
   
   ArraySetAsSeries(BarRange, true);
//---- indicators
   string sName = "WeeklyScalping Lines";
   IndicatorShortName(sName);
   Comment(sName);
//----
   SetIndexBuffer(0,MavgThisTimeFrame);
   SetIndexBuffer(1,CloseUpperTimeFrame);
//----   
   SetIndexStyle(0,DRAW_LINE,STYLE_SOLID,2);
   SetIndexStyle(1,DRAW_LINE,STYLE_SOLID,4); // close
//----      
   SetIndexLabel(0,"MAvg");
   SetIndexLabel(1,"Close");
//----
   SetIndexBuffer(2,LongEntry);
   SetIndexBuffer(3,LongStop);
   SetIndexBuffer(4,LongTarget);
   SetIndexStyle(2,DRAW_LINE,STYLE_SOLID,4); // long
   SetIndexStyle(3,DRAW_LINE,STYLE_SOLID,2);
   SetIndexStyle(4,DRAW_LINE,STYLE_SOLID,2);   
   SetIndexLabel(2,"LongEntry");
   SetIndexLabel(3,"LongStop");
   SetIndexLabel(4,"LongTarget");
   
   SetIndexBuffer(5,ShortEntry);             // short
   SetIndexBuffer(6,ShortStop);
   SetIndexBuffer(7,ShortTarget);
   SetIndexStyle(5,DRAW_LINE,STYLE_SOLID,4);
   SetIndexStyle(6,DRAW_LINE,STYLE_SOLID,2);
   SetIndexStyle(7,DRAW_LINE,STYLE_SOLID,2);
   SetIndexLabel(5,"ShortEntry");
   SetIndexLabel(6,"ShortStop");
   SetIndexLabel(7,"ShortTarget");
    
//----         
   maxPeriod = Period_ATRweekly;
   SetIndexDrawBegin(0, maxPeriod);
   SetIndexDrawBegin(1, maxPeriod);
   SetIndexDrawBegin(2, maxPeriod);
   SetIndexDrawBegin(3, maxPeriod);
   SetIndexDrawBegin(4, maxPeriod);
   SetIndexDrawBegin(5, maxPeriod);
   SetIndexDrawBegin(6, maxPeriod);
   SetIndexDrawBegin(7, maxPeriod);
   return(0);
}

int deinit()
{ return(0); }

//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
{
if (thisTimeFrame > upperTimeFrame) return(0);
int i,y,ind, limit ;
   
   ArrayResize(BarRange, Bars);

   int counted_bars = IndicatorCounted();
   if(counted_bars > 0) counted_bars--;
   limit = Bars - counted_bars;
   
//---- MAvg this TimeFrame -------------------------------------------
   for(i = 0; i <limit; i++) 
   {
      MavgThisTimeFrame[i]  = iMA(NULL, thisTimeFrame, Period_ShortAvg, 0, MODE_SMA, PRICE_MEDIAN, i);
   }   
   
   //---- Upper TimeFrame ............................................
   datetime TimeArray[];   
   ArrayCopySeries(TimeArray,MODE_TIME,Symbol(),upperTimeFrame);   
   
   for(i=0, y=0; i<limit; i++)  {
      if (Time[i] < TimeArray[y]) y++; 
   
      /***********************************************************   
      Add your main indicator loop below.  You can reference an existing
         indicator with its iName  or iCustom.
      Rule 1:  Add extern inputs above for all neccesary values   
      Rule 2:  Use 'TimeFrame' for the indicator timeframe
      Rule 3:  Use 'y' for the indicator's shift value
      ***********************************************************/  

      BarRange[i] = iATR(NULL,upperTimeFrame, Period_ATRweekly, y+1);     
      CloseUpperTimeFrame[i]=iClose(NULL,upperTimeFrame,y+1); 
      // Trading levels
      double dEntryOffset = NormalizeDouble(BarRange[i] * factor_EntryOffset, Digits);
      double dStopLoss    = NormalizeDouble(dEntryOffset * factor_StopLoss, Digits);
      double dTarget      = NormalizeDouble(dEntryOffset * factor_Target, Digits);

      LongEntry[i] = CloseUpperTimeFrame[i] + dEntryOffset;
      LongStop[i]  = LongEntry[i] - dStopLoss;
      LongTarget[i]= LongEntry[i] + dTarget;
      
      ShortEntry[i] = CloseUpperTimeFrame[i] - dEntryOffset;
      ShortStop[i]  = ShortEntry[i] + dStopLoss;
      ShortTarget[i]= ShortEntry[i] - dTarget;
   }
//----
   return(0);
}
//+------------------------------------------------------------------+